@@ -23,7 +23,7 @@ if TYPE_CHECKING:
     from poetry.core.packages.package import Package
     from tomlkit.items import InlineTable
 
-    from poetry.repositories import Pool
+    from poetry.repositories import RepositoryPool
 
 Requirements = Dict[str, Union[str, Mapping[str, Any]]]
 
@@ -66,7 +66,7 @@ The <c1>init</c1> command creates a basic <comment>pyproject.toml</> file in the
     def __init__(self) -> None:
         super().__init__()
 
-        self._pool: Pool | None = None
+        self._pool: RepositoryPool | None = None
 
     def handle(self) -> int:
         from pathlib import Path
@@ -77,7 +77,17 @@ The <c1>init</c1> command creates a basic <comment>pyproject.toml</> file in the
         from poetry.layouts import layout
         from poetry.utils.env import SystemEnv
 
-        pyproject = PyProjectTOML(Path.cwd() / "pyproject.toml")
+        project_path = Path.cwd()
+
+        if self.io.input.option("directory"):
+            project_path = Path(self.io.input.option("directory"))
+            if not project_path.exists() or not project_path.is_dir():
+                self.line_error(
+                    "<error>The --directory path is not a directory.</error>"
+                )
+                return 1
+
+        pyproject = PyProjectTOML(project_path / "pyproject.toml")
 
         if pyproject.file.exists():
             if pyproject.is_poetry_project():
@@ -462,15 +472,15 @@ You can specify a package in the following forms:
 
         return package
 
-    def _get_pool(self) -> Pool:
-        from poetry.repositories import Pool
+    def _get_pool(self) -> RepositoryPool:
+        from poetry.repositories import RepositoryPool
         from poetry.repositories.pypi_repository import PyPiRepository
 
         if isinstance(self, EnvCommand):
             return self.poetry.pool
 
         if self._pool is None:
-            self._pool = Pool()
+            self._pool = RepositoryPool()
             self._pool.add_repository(PyPiRepository())
 
         return self._pool
