@@ -364,8 +364,8 @@ class Git:
     def is_using_legacy_client() -> bool:
         from poetry.config.config import Config
 
-        legacy_client: bool = (
-            Config.create().get("experimental", {}).get("system-git-client", False)
+        legacy_client: bool = Config.create().get(
+            "experimental.system-git-client", False
         )
         return legacy_client
 
